@@ -92,7 +92,7 @@ class TestRun:
     def __str__(self) -> str:
         output = f"<TestRun '{self.name}'\n"
         output += f'\truns:       {self.repeat:,}\n'
-        output += f'\tavg mem:    {self.memory:.4}Mib>'
+        output += f'\tavg mem:    {self.memory:.4}Mib\n'
         output += f'\tavg time:   {self.avg_time:.4}s\n'
         output += f'\ttotal time: {self.time:.4}s\n'
         return output
